@@ -4,7 +4,12 @@ import logging
 from typing import Any, Callable, Dict, Optional, Tuple, Type
 
 import orjson
-from jsondaora import DeserializationError, asdataclass, dataclass_asjson
+from jsondaora import (
+    DeserializationError,
+    asdataclass,
+    dataclass_asjson,
+    typed_dict_asjson,
+)
 
 from .events.handler import EventsHandler
 from .exceptions import (
@@ -41,6 +46,9 @@ class AsyncApi:
         )
 
     async def publish(self, channel_id: str, message: Any) -> None:
+        if isinstance(message, dict):
+            return await self.publish_json(channel_id, message)
+
         await self.events_handler.publish(
             channel=channel_id,
             message=self.parse_message(channel_id, message).decode(),
@@ -181,6 +189,9 @@ class AsyncApi:
         type_ = self.publish_payload_type(channel_id)
 
         if type_:
+            if issubclass(type_, dict):
+                return typed_dict_asjson(message, type_)
+
             if not isinstance(message, type_):
                 raise InvalidMessageError(message, type_)
 
